==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/WindowsInformationProtectionIPRangeCollection.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.schema.SchemaInfo;


/**
 * <i>“Windows Information Protection IP Range Collection”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "displayName", 
    "ranges"})
@JsonInclude(Include.NON_NULL)
public class WindowsInformationProtectionIPRangeCollection implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("ranges")
    protected List<IpRange> ranges;

    @JsonProperty("ranges@nextLink")
    protected String rangesNextLink;

    protected WindowsInformationProtectionIPRangeCollection() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.windowsInformationProtectionIPRangeCollection";
    }

    /**
     * <i>“Display name”</i>
     * 
     * @return property displayName
     */
    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code displayName}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“Display name”</i>
     * 
     * @param displayName
     *            new value of {@code displayName} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code displayName} field changed
     */
    public WindowsInformationProtectionIPRangeCollection withDisplayName(String displayName) {
        WindowsInformationProtectionIPRangeCollection _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.windowsInformationProtectionIPRangeCollection");
        _x.displayName = displayName;
        return _x;
    }

    /**
     * <i>“Collection of ip ranges”</i>
     * 
     * @return property ranges
     */
    @Property(name="ranges")
    @JsonIgnore
    public CollectionPage<IpRange> getRanges() {
        return new CollectionPage<IpRange>(contextPath, IpRange.class, ranges, Optional.ofNullable(rangesNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    /**
     * <i>“Collection of ip ranges”</i>
     * 
     * @return property ranges
     */
    @Property(name="ranges")
    @JsonIgnore
    public CollectionPage<IpRange> getRanges(HttpRequestOptions options) {
        return new CollectionPage<IpRange>(contextPath, IpRange.class, ranges, Optional.ofNullable(rangesNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), options);
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String displayName;
        private List<IpRange> ranges;
        private String rangesNextLink;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“Display name”</i>
         * 
         * @param displayName
         *            value of {@code displayName} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        /**
         * <i>“Collection of ip ranges”</i>
         * 
         * @param ranges
         *            value of {@code ranges} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder ranges(List<IpRange> ranges) {
            this.ranges = ranges;
            this.changedFields = changedFields.add("ranges");
            return this;
        }

        /**
         * <i>“Collection of ip ranges”</i>
         * 
         * @param ranges
         *            value of {@code ranges} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder ranges(IpRange... ranges) {
            return ranges(Arrays.asList(ranges));
        }

        /**
         * <i>“Collection of ip ranges”</i>
         * 
         * @param rangesNextLink
         *            value of {@code ranges@nextLink} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder rangesNextLink(String rangesNextLink) {
            this.rangesNextLink = rangesNextLink;
            this.changedFields = changedFields.add("ranges");
            return this;
        }

        public WindowsInformationProtectionIPRangeCollection build() {
            WindowsInformationProtectionIPRangeCollection _x = new WindowsInformationProtectionIPRangeCollection();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.windowsInformationProtectionIPRangeCollection";
            _x.displayName = displayName;
            _x.ranges = ranges;
            _x.rangesNextLink = rangesNextLink;
            return _x;
        }
    }

    private WindowsInformationProtectionIPRangeCollection _copy() {
        WindowsInformationProtectionIPRangeCollection _x = new WindowsInformationProtectionIPRangeCollection();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.displayName = displayName;
        _x.ranges = ranges;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("WindowsInformationProtectionIPRangeCollection[");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("ranges=");
        b.append(this.ranges);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/WindowsInformationProtectionIPRangeCollection.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;


/**
 * <i>“Windows Information Protection IP Range Collection”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "displayName", 
    "ranges"})
@JsonInclude(Include.NON_NULL)
public class WindowsInformationProtectionIPRangeCollection implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("ranges")
    protected List<IpRange> ranges;

    @JsonProperty("ranges@nextLink")
    protected String rangesNextLink;

    protected WindowsInformationProtectionIPRangeCollection() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.windowsInformationProtectionIPRangeCollection";
    }

    /**
     * <i>“Display name”</i>
     * 
     * @return property displayName
     */
    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code displayName}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“Display name”</i>
     * 
     * @param displayName
     *            new value of {@code displayName} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code displayName} field changed
     */
    public WindowsInformationProtectionIPRangeCollection withDisplayName(String displayName) {
        WindowsInformationProtectionIPRangeCollection _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.windowsInformationProtectionIPRangeCollection");
        _x.displayName = displayName;
        return _x;
    }

    /**
     * <i>“Collection of ip ranges”</i>
     * 
     * @return property ranges
     */
    @Property(name="ranges")
    @JsonIgnore
    public CollectionPage<IpRange> getRanges() {
        return new CollectionPage<IpRange>(contextPath, IpRange.class, this.ranges, Optional.ofNullable(rangesNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    /**
     * <i>“Collection of ip ranges”</i>
     * 
     * @param options
     *            specify connect and read timeouts
     * @return property ranges
     */
    @Property(name="ranges")
    @JsonIgnore
    public CollectionPage<IpRange> getRanges(HttpRequestOptions options) {
        return new CollectionPage<IpRange>(contextPath, IpRange.class, this.ranges, Optional.ofNullable(rangesNextLink), Collections.emptyList(), options);
    }

    public WindowsInformationProtectionIPRangeCollection withUnmappedField(String name, Object value) {
        WindowsInformationProtectionIPRangeCollection _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String displayName;
        private List<IpRange> ranges;
        private String rangesNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“Display name”</i>
         * 
         * @param displayName
         *            value of {@code displayName} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        /**
         * <i>“Collection of ip ranges”</i>
         * 
         * @param ranges
         *            value of {@code ranges} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder ranges(List<IpRange> ranges) {
            this.ranges = ranges;
            this.changedFields = changedFields.add("ranges");
            return this;
        }

        /**
         * <i>“Collection of ip ranges”</i>
         * 
         * @param ranges
         *            value of {@code ranges} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder ranges(IpRange... ranges) {
            return ranges(Arrays.asList(ranges));
        }

        /**
         * <i>“Collection of ip ranges”</i>
         * 
         * @param rangesNextLink
         *            value of {@code ranges@nextLink} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder rangesNextLink(String rangesNextLink) {
            this.rangesNextLink = rangesNextLink;
            this.changedFields = changedFields.add("ranges");
            return this;
        }

        public WindowsInformationProtectionIPRangeCollection build() {
            WindowsInformationProtectionIPRangeCollection _x = new WindowsInformationProtectionIPRangeCollection();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.windowsInformationProtectionIPRangeCollection";
            _x.displayName = displayName;
            _x.ranges = ranges;
            _x.rangesNextLink = rangesNextLink;
            return _x;
        }
    }

    private WindowsInformationProtectionIPRangeCollection _copy() {
        WindowsInformationProtectionIPRangeCollection _x = new WindowsInformationProtectionIPRangeCollection();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.displayName = displayName;
        _x.ranges = ranges;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("WindowsInformationProtectionIPRangeCollection[");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("ranges=");
        b.append(this.ranges);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
